import { useEffect, useState } from "react";
import { connect } from "react-redux";
import OrderIndex from "./components/order/OrderIndex";
import NoOrders from "./components/order/NoOrders";
import { fetchOrders } from "./actions/order_actions";
import FilterSearch from "./components/filter/FilterSearch";
import Button from "./components/atoms/Button";

const App = ({ orders, fetchOrders }) => {
  const [ordersToShow, setOrdersToShow] = useState(orders);
  const [fetchAttempted, setFetchAttempted] = useState(false);
  const [collapseAll, setCollapseAll] = useState(false);
  const [expandAll, setExpandAll] = useState(false);

  useEffect(() => {
    if (!fetchAttempted) {
      fetchOrders();
      setFetchAttempted(true);
    }
    setOrdersToShow(orders);
  }, [orders, fetchOrders, fetchAttempted]);

  return (
    <div className="app">
      <div className="fs-collapse">
        <FilterSearch setOrdersToShow={setOrdersToShow} />
        <div className="collapse-expand">
          <Button
            className="collapse-btn"
            onClick={() => setCollapseAll(true)}
            text={`Collapse All`}
          />
          <Button
            className="expand-btn"
            onClick={() => setExpandAll(true)}
            text={`Expand All`}
          />
        </div>
      </div>
      {ordersToShow.allIds.length ? (
        <OrderIndex
          orders={ordersToShow}
          collapseAll={collapseAll}
          expandAll={expandAll}
          setCollapseAll={setCollapseAll}
          setExpandAll={setExpandAll}
        />
      ) : (
        <NoOrders />
      )}
    </div>
  );
};

const mapStateToProps = (state) => ({
  orders: state.entities.orders,
});

const mapDispatchToProps = (dispatch) => ({
  fetchOrders: () => dispatch(fetchOrders()),
});

export default connect(mapStateToProps, mapDispatchToProps)(App);
