import { useEffect, useState } from "react";
import { connect } from "react-redux";
import Button from "../atoms/Button";

const Filter = ({ orders, filtersOn, setFiltersOn, setOrdersToShow }) => {
  const [all, setAll] = useState(false);
  const [received, setReceived] = useState(false);
  const [fulfilled, setFulfilled] = useState(false);
  const [cancelled, setCancelled] = useState(false);

  const RECEIVED = "RECEIVED";
  const FULFILLED = "FULFILLED";
  const CANCELLED = "CANCELLED";

  const reset = () => {
    setAll(true);
    setFiltersOn(true);
    setReceived(false);
    setFulfilled(false);
    setCancelled(false);
  };
  const receive = () => {
    setAll(false);
    setFiltersOn(true);
    setReceived(!received);
    if (received && !fulfilled && !cancelled) {
      setAll(true);
    }
  };
  const fulfill = () => {
    setAll(false);
    setFiltersOn(true);
    setFulfilled(!fulfilled);
    if (!received && fulfilled && !cancelled) {
      setAll(true);
    }
  };
  const cancel = () => {
    setAll(false);
    setFiltersOn(true);
    setCancelled(!cancelled);
    if (!received && !fulfilled && cancelled) {
      setAll(true);
    }
  };

  useEffect(() => {
    if (!filtersOn) {
      setAll(false);
      setReceived(false);
      setFulfilled(false);
      setCancelled(false);
    } else if (all || (!all && !received && !fulfilled && !cancelled)) {
      setOrdersToShow(orders);
    } else {
      const newOrders = { allIds: [], byId: {} };
      orders.allIds.forEach((wareId) => {
        const order = orders.byId[wareId];
        switch (order.status) {
          case RECEIVED:
            if (all || received) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          case FULFILLED:
            if (all || fulfilled) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          case CANCELLED:
            if (all || cancelled) {
              newOrders.allIds.push(wareId);
              newOrders.byId[wareId] = order;
            }
            break;
          default:
            break;
        }
      });
      setOrdersToShow(newOrders);
    }
  }, [orders, setOrdersToShow, filtersOn, all, received, fulfilled, cancelled]);

  if (!orders.allIds.length) return null;

  return (
    <div className="filter">
      <div className="text">Filter:</div>

      <div className="filter-btns">
        <Button
          className={`filter-all ${all ? "selected" : ""}`}
          onClick={reset}
          text="All"
        />
        <Button
          className={`filter-rec ${received ? "selected" : ""}`}
          onClick={receive}
          text="Received"
        />
        <Button
          className={`filter-ful ${fulfilled ? "selected" : ""}`}
          onClick={fulfill}
          text="Fulfilled"
        />
        <Button
          className={`filter-can ${cancelled ? "selected" : ""}`}
          onClick={cancel}
          text="Cancelled"
        />
      </div>
    </div>
  );
};
const mapStateToProps = (state) => ({
  orders: state.entities.orders,
});

const mapDispatchToProps = (dispatch) => ({});

export default connect(mapStateToProps, mapDispatchToProps)(Filter);
