import { useState } from "react";
import { connect } from "react-redux";
import Select from "../atoms/Select";
import Input from "../atoms/Input";
import Button from "../atoms/Button";

const Search = ({ orders, setOrdersToShow, setFiltersOn }) => {
  const [searchInput, setSearchInput] = useState("");
  const [searchBy, setSearchBy] = useState("");
  const [inputError, setInputError] = useState(false);
  const [byError, setByError] = useState(false);

  const searchOptions = ["Warehouse ID", "Order ID"];

  const search = () => {
    setInputError(false);
    setByError(false);
    if (!searchInput.length && !searchBy.length) {
      setInputError(true);
      setByError(true);
    } else if (!searchInput.length) {
      setInputError(true);
    } else if (!searchBy.length) {
      setByError(true);
    } else {
      const searchResult = { allIds: [], byId: {} };
      const searchedOrder =
        searchBy === searchOptions[0]
          ? orders.byId[searchInput]
          : searchBy === searchOptions[1]
          ? orders.byOrderId[searchInput]
          : null;

      if (searchedOrder) {
        searchResult.allIds.push(searchedOrder.id);
        searchResult.byId[searchedOrder.id] = searchedOrder;
      }
      if (searchBy.length) {
        setOrdersToShow(searchResult);
      }
      setSearchInput("");
      setFiltersOn(false);
    }
  };

  const handleInputBlur = (e) => {
    if (!e.target.value.length) {
      setInputError(true);
    }
  };

  const handleSearchEnter = (e) => {
    if (e.key === "Enter") {
      search();
    }
  };

  return (
    <div className="search">
      <div className="text">Search:</div>
      <Select
        className={byError ? "search-select-error" : ""}
        defaultVal={"Choose one.."}
        value={searchBy}
        options={searchOptions}
        onChange={(e) => {
          setByError(false);
          setSearchBy(e.target.selectedOptions[0].value);
        }}
      />
      <Input
        className={inputError ? "search-input-error" : ""}
        placeholder={"Search by ID"}
        value={searchInput}
        onChange={(e) => {
          setInputError(false);
          setSearchInput(e.target.value);
        }}
        onBlur={handleInputBlur}
        onKeyPress={handleSearchEnter}
      />
      <Button className="search-btn" text="Search" onClick={search} />
    </div>
  );
};

const mapStateToProps = (state) => ({
  orders: state.entities.orders,
});

const mapDispatchToProps = (dispatch) => ({});

export default connect(mapStateToProps, mapDispatchToProps)(Search);
