import ItemDetails from "./ItemDetails";

const OrderDetails = ({ order, showDetails }) => {
  const createdDate = new Date(order.createdAt);
  const modifiedDate = new Date(order.modifiedAt);
  const status =
    order.status[0].toUpperCase() + order.status.substr(1).toLowerCase();

  const dateToString = (date) => {
    const month = date.toLocaleString("default", { month: "short" });
    const day = date.getDate();
    const year = date.getFullYear();
    const hour = date.getHours();
    const cHour = hour > 12 ? hour - 12 : hour;
    const minute = date.getMinutes();
    const time = `${cHour > 9 ? cHour : `0${cHour}`}:${minute > 9 ? minute : `0${minute}`}`;
    return `${month} ${day > 9 ? day : `0${day}`}, ${year} at ${time} ${hour > 11 ? "PM" : "AM"}`;
  };

  return (
    <div className={`order-details ${showDetails ? "animate" : ""}`}>
      <div className="order-details-container">
        <div className="order-details-header">
          <div className="order-details-name">Order Details:</div>
          <div className="order-details-dates">
            <div>
              <div>Created on:</div>
              <div>{dateToString(createdDate)}</div>
            </div>
            {order.modifiedAt ? (
              <div>
                <div>{`${status} on:`}</div>
                <div>{dateToString(modifiedDate)}</div>
              </div>
            ) : null}
          </div>
        </div>
        <table className="order-detail-table">
          <thead>
            <tr>
              <th>SKU #</th>
              <th>Name</th>
              <th>Quantity</th>
              <th>Price</th>
            </tr>
          </thead>
          <tbody>
            {order.orderItems.map((item) => (
              <ItemDetails key={item.itemId} item={item} />
            ))}
          </tbody>
        </table>
        {`Warehouse Order #: ${order.id}`}
      </div>
    </div>
  );
};

export default OrderDetails;
