package com.ascendfinalproject.warehouse.services;

import com.ascendfinalproject.warehouse.models.Item;
import com.ascendfinalproject.warehouse.models.OrderResponse;
import com.ascendfinalproject.warehouse.models.WarehouseOrder;
import com.ascendfinalproject.warehouse.repositories.WarehouseOrderRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Flux;
import reactor.core.publisher.Mono;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.Date;
import java.util.List;

@Service
public class WarehouseOrderService {

  @Autowired
  WarehouseOrderRepository orderRepository;

  public Mono<WarehouseOrder> getById(String id) {
    return orderRepository.findById(id);
  }

  public Flux<WarehouseOrder> getOrders() {
    return orderRepository.findAll();
  }

  public Mono<WarehouseOrder> createOrder(WarehouseOrder order) {
      order.setStatus("RECEIVED");
      order.setCreatedAt(new Date(System.currentTimeMillis()));
      List<Item> itemList = Arrays.asList(
              new Item("3", "Hamburger", 3, 3, 33),
              new Item("4", "Sausage", 4, 5, 66),
              new Item("5", "Fries", 3, 4, 33));
      order.setOrderItems(itemList);
      order.setAddress("123 apple st");
      return orderRepository.save(order);
  }

  public Mono<WarehouseOrder> updateOrder(WarehouseOrder order, String id) {
    return orderRepository.findById(id)
        .flatMap(existingOrder -> {
          existingOrder.setStatus(order.getStatus());
          existingOrder.setModifiedAt(new Date(System.currentTimeMillis()));
          return orderRepository.save(existingOrder);
        });
  }

  public Mono<Void> deleteOrder(String id) {
    return orderRepository.deleteById(id);
  }

  public Mono<Void> deleteAllOrders() {
    return orderRepository.deleteAll();
  }


}
